# Packets

!!! bug "Pending rewrite of this page"

    This page will be rewritten in the near future and split it into multiple pages for the individual game states,
    with the play state possibly being subdivided into even more pages. Currently, this page shows all implemented
    packets in mcproto. This split will happen once play state packets are introduced.

## Base classes and interaction functions

::: mcproto.packets
    options:
        heading_level: 3

## Handshaking gamestate

::: mcproto.packets.handshaking.handshake
    options:
        heading_level: 3

## Status gamestate

::: mcproto.packets.status.ping
    options:
        heading_level: 3

::: mcproto.packets.status.status
    options:
        heading_level: 3

## Login gamestate

::: mcproto.packets.login.login
    options:
        heading_level: 3

## Play gamestate

!!! bug "Work In Progress"

    Packets for the Play gamestate aren't yet implemented.
